@@ -125,8 +125,8 @@ INSTALLED_APPS = (
     # 'editor',
     # 'statistics',
     # 'cloud',
-    # 'newsletter_extension',
-    # 'document',
+    'newsletter_extension',
+    'document',
     'integration',
     # 'api',
 )
