@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10436 2017-11-05 03:14:46Z David $
+# $Id: Mailer.py 10456 2017-11-07 09:20:54Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10436 $
+# $Revision: 10456 $
 
 import os
 import random
@@ -336,7 +336,6 @@ class CloudMailer(Mailer):
             self.logger.info(
                 '[%d]_START: Send mail to contact<%d>.' %
                 (newsletterId, contactId))
-
             if self.fakeMail:
                 result = self.testSend(contact)
                 resultMessage = 'Send test mail success.'
@@ -344,7 +343,7 @@ class CloudMailer(Mailer):
                 subject = self.build_title_content(contact)
                 replyTo = smart_str(self.newsletter.header_reply)
                 contentHtml = self.buildEmailContent(contact)
-                a = 1/0
+                
                 result = self.smtp.sendMail(
                     contact,
                     subject,
@@ -356,11 +355,11 @@ class CloudMailer(Mailer):
                 
             else:
                 message = self.build_message(contact)
-                content = message.as_string()
-                sender = u'test@nuwainfo.com'
-                to = contact.email
-
-                self.smtp.sendmail(sender, to, content)
+                self.smtp.sendmail(
+                    smart_str(self.newsletter.header_sender),
+                    contact.email,
+                    message.as_string()
+                )
                 result = True
                 resultMessage = 'Send mail success.'
 
@@ -379,6 +378,14 @@ class CloudMailer(Mailer):
             self.logger.error(
                 '[%d]_FAILED: Send mail to contact<%d> failed, %s.' %
                 (newsletterId, contactId, _eMsg))
+
+            # Record error message  to db.
+            ErrorMessage.objects.create(
+                message=(resultMessage + _eMsg), 
+                contact=contact,
+                newsletter=self.newsletter
+            )
+
         except Exception as e:
             _eMsg = getComment(e)
             resultMessage = 'Send mail failed: %s.' % _eMsg
@@ -411,6 +418,14 @@ class CloudMailer(Mailer):
 
             else:
                 status = ContactMailingStatus.ERROR
+
+            # Record error message  to db.
+            ErrorMessage.objects.create(
+                message=(resultMessage + errorMessage), 
+                contact=contact,
+                newsletter=self.newsletter
+            )
+
         finally:
             self.logger.info(
                 '[%d]_END: Send mail to contact<%d> end.' %
@@ -422,8 +437,6 @@ class CloudMailer(Mailer):
             newsletter=self.newsletter, contact=contact, status=status
         )
 
-        # FIXME # Add record error message  to db here.
-
         return {'result': result , 'message': resultMessage, 'id': contactId}
 
     def run(self):
