@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: generate_test_data.py 10079 2017-07-03 13:52:00Z David $
+# $Id: generate_test_data.py 10083 2017-07-04 08:36:29Z David $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-07-03 21:52:00 +0800 (Mon, 03 Jul 2017) $
-# $Revision: 10079 $
+# $Date: 2017-07-04 16:36:29 +0800 (二, 04  7 2017) $
+# $Revision: 10083 $
 
 import datetime
 import random
@@ -22,10 +22,16 @@ import string
 def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
                        sent=90, error=10, invalid=5, opened=80, openedOnSite=30,
                        linkOpened=60, unsubscription=10, bounce=5, complain=5,
-                       rejected=5, sendTest=90):
+                       reject=5, sendTest=90):
     """
     Create statistic test data.
     
+    @param contactNum The amount of contact.
+                      The default value is 100.    
+    @param testContactNum The amount of test contact.
+                          The default value is 5.  
+    @param testDays The range of test day.
+                    The default value is 15.   
     @param sent The percentage of sent email.
                 The default value is 90.
                 NOTICE: 'sent' plus 'error' should equal to 100.
@@ -39,9 +45,9 @@ def createStatTestData(contactNum=100, testContactNum=5, testDays=15,
                   NOTICE: 'opened' include 'opened unique', 'opened on site' and 
                   'link opened', so 'opened' should bigger than 'opened on site'
                   and 'link opened'.           
-    @param opened_on_site The percentage of email opened on site.
+    @param openedOnSite The percentage of email opened on site.
                           The default value is 30.
-    @param link_opened The percentage of link opened email.
+    @param linkOpened The percentage of link opened email.
                        The default value is 60.
     @param unsubscription The percentage of unsubscribe email.
                           The default value is 10.
@@ -289,7 +295,7 @@ class Command(BaseCommand):
     named 'test.json'. You can setting option argument to create your own test
     data as well.
     
-    A test server can be run with the test data we just created by using
+    A test server can be run with the test data we just created by doing
     following steps:
     
     1) Add a folder called 'fixture' in any app in your project.
@@ -297,11 +303,12 @@ class Command(BaseCommand):
     3) Copy 'initial_data.json' from demo project into 'fixture'
     4) Run command 
        python manage.py testserver --addrport='YOURPORT' initial_data 'TESTDATA'
-       TESTDATA would be the file name of test data.
+       TESTDATA would be the file name of test data. Then, a test server will 
+       start.
        example: python manage.py testserver --addrport=7788 test initial_data
-    5) Then a test server will start.
     
-    Related ticket: https://code.nuwainfo.com/trac/mercurius/ticket/2741
+    See more on related ticket: 
+    https://code.nuwainfo.com/trac/mercurius/ticket/2741
     
     @param contact_num The Amount of contact for testing.
                        The default is 100.
@@ -449,7 +456,7 @@ class Command(BaseCommand):
         _reject = int(options['reject'])
         _sendTest = int(options['sendTest'])
         
-        if options['randomData'] == 'T':
+        if options['randomData'] == True:
             _sent = random.randint(80, 100)
             _error = 100 - _sent
             _invalid = random.randint(0, int(_sent/4))
